# pylint: disable=no-member,wrong-import-position,too-many-lines,no-name-in-module
import base64
import os

import instill.protogen.artifact.artifact.v1alpha.artifact_pb2 as artifact_interface


def get_file_type(file_path, file_extension):
    # Dictionary mapping file extensions to file types
    extension_mapping = {
        ".pdf": "PDF",
        ".html": "HTML",
        ".htm": "HTML",
        ".md": "MARKDOWN",
        ".markdown": "MARKDOWN",
        ".doc": "DOC",
        ".docx": "DOCX",
        ".ppt": "PPT",
        ".pptx": "PPTX",
        ".xls": "XLS",
        ".xlsx": "XLSX",
        ".txt": "TEXT",
        ".log": "TEXT",
        ".ini": "TEXT",
        ".csv": "TEXT",
    }

    # Check if the file extension is in our mapping
    file_type = extension_mapping.get(file_extension.lower(), "UNKNOWN")

    # If file type is unknown, try to guess based on content
    if file_type == "UNKNOWN":
        with open(file_path, "rb") as file:
            content = file.read(4096)  # Read first 4KB of the file

            # Check for PDF signature
            if content.startswith(b"%PDF-"):
                file_type = "PDF"
            # Check for HTML signature
            elif b"<!DOCTYPE html>" in content.lower() or b"<html" in content.lower():
                file_type = "HTML"
            # Check for Office Open XML formats (DOCX, PPTX, XLSX)
            elif content.startswith(b"PK\x03\x04"):
                if "[Content_Types].xml" in str(content) and "word/" in str(content):
                    file_type = "DOCX"
                elif "[Content_Types].xml" in str(content) and "ppt/" in str(content):
                    file_type = "PPTX"
                elif "[Content_Types].xml" in str(content) and "xl/" in str(content):
                    file_type = "XLSX"

    if file_type == "UNKNOWN":
        raise ValueError(f"Unsupported file type: {file_extension}")

    # Convert to uppercase and add prefix
    return f"FILE_TYPE_{file_type.upper()}"


def process_file(file_path) -> artifact_interface.File:
    # Check if the file path exists
    if not os.path.exists(file_path):
        raise FileNotFoundError(f"File does not exist: {file_path}")

    # Get file name and extension
    file_name = os.path.basename(file_path)
    _, file_extension = os.path.splitext(file_name)

    # Check file type
    file_type = get_file_type(file_path, file_extension)

    # Read file content and encode to base64
    with open(file_path, "rb") as file:
        file_content = file.read()
        base64_encoded = base64.b64encode(file_content).decode("utf-8")

    return artifact_interface.File(
        name=file_name, type=file_type, content=base64_encoded
    )


# Example usage
# file_path = "/tmp/example.pdf"
# result = process_file(file_path)
# print(result.name)
# print((result.type))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/qa.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import chunk_pb2 as artifact_dot_artifact_dot_v1alpha_dot_chunk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"artifact/artifact/v1alpha/qa.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a%artifact/artifact/v1alpha/chunk.proto\"\x8d\x01\n\x18QuestionAnsweringRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x1d\n\ncatalog_id\x18\x02 \x01(\tR\tcatalogId\x12\x1a\n\x08question\x18\x03 \x01(\tR\x08question\x12\x13\n\x05top_k\x18\x04 \x01(\x05R\x04topK\"\x86\x01\n\x19QuestionAnsweringResponse\x12\x16\n\x06\x61nswer\x18\x01 \x01(\tR\x06\x61nswer\x12Q\n\x0esimilar_chunks\x18\x02 \x03(\x0b\x32*.artifact.artifact.v1alpha.SimilarityChunkR\rsimilarChunksB\xfb\x01\n\x1d\x63om.artifact.artifact.v1alphaB\x07QaProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.qa_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\007QaProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _globals['_QUESTIONANSWERINGREQUEST']._serialized_start=105
  _globals['_QUESTIONANSWERINGREQUEST']._serialized_end=246
  _globals['_QUESTIONANSWERINGRESPONSE']._serialized_start=249
  _globals['_QUESTIONANSWERINGRESPONSE']._serialized_end=383
# @@protoc_insertion_point(module_scope)



# pylint: disable=no-member,wrong-import-position,no-name-in-module
from typing import Optional, Tuple, Union

import grpc
from google.longrunning.operations_pb2 import Operation
from google.protobuf import json_format
from google.protobuf.field_mask_pb2 import FieldMask
from google.protobuf.struct_pb2 import Struct

import instill.protogen.vdp.pipeline.v1beta.pipeline_pb2 as pipeline_interface
from instill.clients import InstillClient
from instill.resources.resource import Resource
from instill.utils.logger import Logger


class Pipeline(Resource):
    def __init__(
        self,
        client: InstillClient,
        namespace_id: str,
        pipeline_id: str,
        recipe: Union[Struct, None] = None,
    ) -> None:
        super().__init__()
        self.client = client
        get_resp = None
        pipeline = None
        get_resp = client.pipeline.get_pipeline(
            namespace_id=namespace_id,
            pipeline_id=pipeline_id,
        )
        if get_resp is None:
            pipeline = client.pipeline.create_pipeline(
                namespace_id=namespace_id,
                recipe=recipe,
            ).pipeline
            if pipeline is None:
                raise BaseException("pipeline creation failed")
        else:
            pipeline = get_resp.pipeline

        self.resource = pipeline

    def __call__(
        self,
        task_inputs: list,
        silent: bool = False,
    ) -> Optional[Tuple[list, pipeline_interface.TriggerMetadata]]:
        resp = self.client.pipeline.trigger(
            self.resource.id,
            task_inputs,
            silent=silent,
        )
        if resp is not None:
            return resp.outputs, resp.metadata
        return resp

    @property
    def client(self):
        return self._client

    @client.setter
    def client(self, client: InstillClient):
        self._client = client

    @property
    def resource(self):
        return self._resource

    @resource.setter
    def resource(self, resource: pipeline_interface.Pipeline):
        self._resource = resource

    def _update(self):
        self.resource = self.client.pipeline.get_pipeline(name=self.resource.id)

    def get_operation(self, operation: Operation, silent: bool = False):
        response = self.client.pipeline.get_operation(
            operation.name,
            silent=silent,
        )
        if response is not None:
            return response.operation
        return response

    def trigger_async(
        self,
        task_inputs: list,
        silent: bool = False,
    ) -> Operation:
        response = self.client.pipeline.trigger_async(
            self.resource.id,
            task_inputs,
            silent=silent,
        )
        if response is not None:
            return response.operation
        return response

    def get_recipe(self) -> dict:
        return json_format.MessageToDict(self.resource.recipe)

    def update_recipe(self, recipe: Struct, silent: bool = False):
        pipeline = self.resource
        pipeline.recipe.CopyFrom(recipe)
        self.client.pipeline.update_pipeline(
            pipeline,
            FieldMask(paths=["recipe"]),
            silent=silent,
        )
        self._update()

    def validate_pipeline(self, silent: bool = True) -> bool:
        try:
            self.client.pipeline.validate_pipeline(name=self.resource.id, silent=silent)
            return True
        except grpc.RpcError as rpc_error:
            Logger.w(rpc_error.code())
            Logger.w(rpc_error.details())
            return False

    def delete(self, silent: bool = False):
        if self.resource is not None:
            self.client.pipeline.delete_pipeline(self.resource.id, silent=silent)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import sys
import typing
import vdp.pipeline.v1beta.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Connection(google.protobuf.message.Message):
    """Connection contains the parameters to communicate with a 3rd party app. A
    component may reference a connection in their setup. One connection may be
    used by several components and pipelines.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Method:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _MethodEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Connection._Method.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        METHOD_UNSPECIFIED: Connection._Method.ValueType  # 0
        """Unspecified."""
        METHOD_DICTIONARY: Connection._Method.ValueType  # 1
        """Key-value collection. The user is responsible of fetching the connection
        details from the 3rd party service.
        """
        METHOD_OAUTH: Connection._Method.ValueType  # 2
        """Access token created via OAuth 2.0 authorization."""

    class Method(_Method, metaclass=_MethodEnumTypeWrapper):
        """Method defines how the connection is set up."""

    METHOD_UNSPECIFIED: Connection.Method.ValueType  # 0
    """Unspecified."""
    METHOD_DICTIONARY: Connection.Method.ValueType  # 1
    """Key-value collection. The user is responsible of fetching the connection
    details from the 3rd party service.
    """
    METHOD_OAUTH: Connection.Method.ValueType  # 2
    """Access token created via OAuth 2.0 authorization."""

    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    INTEGRATION_TITLE_FIELD_NUMBER: builtins.int
    METHOD_FIELD_NUMBER: builtins.int
    SETUP_FIELD_NUMBER: builtins.int
    SCOPES_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    O_AUTH_ACCESS_DETAILS_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """UUID-formatted unique identifier."""
    id: builtins.str
    """ID."""
    namespace_id: builtins.str
    """ID of the namespace owning the connection."""
    integration_id: builtins.str
    """Integration ID. It determines for which type of components can reference
    this connection.
    """
    integration_title: builtins.str
    """Integration title. This helps the console display the results grouped by
    integration ID without needing an extra call to fetch title by integration
    ID.
    """
    method: global___Connection.Method.ValueType
    """Connection method. It references the setup schema provided by the
    integration.
    """
    @property
    def setup(self) -> google.protobuf.struct_pb2.Struct:
        """Connection details. This field is required on creation, optional on view.
        When viewing the connection details, the setup values will be redacted.
        """
    @property
    def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of scopes that identify the resources that the connection will be
        able to access on the user's behalf. This is typically passed on creation
        when the setup has been generated through an OAuth flow with a limited set
        of scopes.
        """
    identity: builtins.str
    """When the connection method is METHOD_OAUTH, this field will hold the
    identity (e.g., email, username) with which the access token has been
    generated.
    """
    @property
    def o_auth_access_details(self) -> google.protobuf.struct_pb2.Struct:
        """When the connection method is METHOD_OAUTH, the access token might come
        with some extra information that might vary across vendors. This
        information is passed as connection metadata.
        """
    view: vdp.pipeline.v1beta.common_pb2.View.ValueType
    """View defines how the connection is presented. The following fields are
    only shown in the FULL view:
    - setup
    - scopes
    - oAuthAccessDetails
    """
    @property
    def create_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""
    @property
    def update_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Last update timestamp."""
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        namespace_id: builtins.str = ...,
        integration_id: builtins.str = ...,
        integration_title: builtins.str = ...,
        method: global___Connection.Method.ValueType = ...,
        setup: google.protobuf.struct_pb2.Struct | None = ...,
        scopes: collections.abc.Iterable[builtins.str] | None = ...,
        identity: builtins.str | None = ...,
        o_auth_access_details: google.protobuf.struct_pb2.Struct | None = ...,
        view: vdp.pipeline.v1beta.common_pb2.View.ValueType = ...,
        create_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        update_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_identity", b"_identity", "_o_auth_access_details", b"_o_auth_access_details", "create_time", b"create_time", "identity", b"identity", "o_auth_access_details", b"o_auth_access_details", "setup", b"setup", "update_time", b"update_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_identity", b"_identity", "_o_auth_access_details", b"_o_auth_access_details", "create_time", b"create_time", "id", b"id", "identity", b"identity", "integration_id", b"integration_id", "integration_title", b"integration_title", "method", b"method", "namespace_id", b"namespace_id", "o_auth_access_details", b"o_auth_access_details", "scopes", b"scopes", "setup", b"setup", "uid", b"uid", "update_time", b"update_time", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_identity", b"_identity"]) -> typing_extensions.Literal["identity"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_o_auth_access_details", b"_o_auth_access_details"]) -> typing_extensions.Literal["o_auth_access_details"] | None: ...

global___Connection = Connection

@typing_extensions.final
class ListNamespaceConnectionsRequest(google.protobuf.message.Message):
    """ListNamespaceConnectionsRequest represents a request to list the connections
    created by a namespace.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID."""
    page_size: builtins.int
    """The maximum number of items to return. The default and cap values are 10 and 100, respectively."""
    page_token: builtins.str
    """Page token. By default, the first page will be returned."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter expression.
    The following filters are supported:
    - `integrationId`
    - `qConnection` (fuzzy search on connection ID, integration title or vendor)

    **Examples**:
    - List connections where app name, vendor or connection ID match `googl`: `q="googl"`.
    - List connections where the component type is `openai` (e.g. to setup a connector within a pipeline): `integrationId="openai"`.
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListNamespaceConnectionsRequest = ListNamespaceConnectionsRequest

@typing_extensions.final
class ListNamespaceConnectionsResponse(google.protobuf.message.Message):
    """ListNamespaceConnectionsResponse contains a paginated list of connections."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Connection]:
        """A list of connections matching the request parameters."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of items."""
    def __init__(
        self,
        *,
        connections: collections.abc.Iterable[global___Connection] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connections", b"connections", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListNamespaceConnectionsResponse = ListNamespaceConnectionsResponse

@typing_extensions.final
class GetNamespaceConnectionRequest(google.protobuf.message.Message):
    """GetNamespaceConnectionRequest represents a request to view the details of a
    connection.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID."""
    connection_id: builtins.str
    """Connection ID."""
    view: vdp.pipeline.v1beta.common_pb2.View.ValueType
    """View allows clients to specify the desired view in the response."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        connection_id: builtins.str = ...,
        view: vdp.pipeline.v1beta.common_pb2.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "connection_id", b"connection_id", "namespace_id", b"namespace_id", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetNamespaceConnectionRequest = GetNamespaceConnectionRequest

@typing_extensions.final
class GetNamespaceConnectionResponse(google.protobuf.message.Message):
    """GetNamespaceConnectionResponse contains the requested connection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___Connection:
        """The requested connection."""
    def __init__(
        self,
        *,
        connection: global___Connection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> None: ...

global___GetNamespaceConnectionResponse = GetNamespaceConnectionResponse

@typing_extensions.final
class CreateNamespaceConnectionRequest(google.protobuf.message.Message):
    """CreateNamespaceConnectionRequest represents a request to create a
    connection.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___Connection:
        """Properties of the connection to be created."""
    def __init__(
        self,
        *,
        connection: global___Connection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> None: ...

global___CreateNamespaceConnectionRequest = CreateNamespaceConnectionRequest

@typing_extensions.final
class CreateNamespaceConnectionResponse(google.protobuf.message.Message):
    """CreateNamespaceConnectionResponse contains the created connection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___Connection:
        """The created connection."""
    def __init__(
        self,
        *,
        connection: global___Connection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> None: ...

global___CreateNamespaceConnectionResponse = CreateNamespaceConnectionResponse

@typing_extensions.final
class UpdateNamespaceConnectionRequest(google.protobuf.message.Message):
    """UpdateNamespaceConnectionRequest represents a request to update a
    connection.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_ID_FIELD_NUMBER: builtins.int
    CONNECTION_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    connection_id: builtins.str
    """ID of the connection to be updated, as present in the database."""
    @property
    def connection(self) -> global___Connection:
        """Connection object with the new properties to be updated. Immutable and
        output-only fields will be ignored. The Setup property must be updated
        in block (no partial update is supported).
        """
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """The update mask specifies the subset of fields that should be modified.

        For more information about this field, see
        https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#field-mask.
        """
    def __init__(
        self,
        *,
        connection_id: builtins.str = ...,
        connection: global___Connection | None = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection", b"connection", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection", b"connection", "connection_id", b"connection_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateNamespaceConnectionRequest = UpdateNamespaceConnectionRequest

@typing_extensions.final
class UpdateNamespaceConnectionResponse(google.protobuf.message.Message):
    """UpdateNamespaceConnectionResponse contains the updated connection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTION_FIELD_NUMBER: builtins.int
    @property
    def connection(self) -> global___Connection:
        """The created connection."""
    def __init__(
        self,
        *,
        connection: global___Connection | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection", b"connection"]) -> None: ...

global___UpdateNamespaceConnectionResponse = UpdateNamespaceConnectionResponse

@typing_extensions.final
class DeleteNamespaceConnectionRequest(google.protobuf.message.Message):
    """DeleteNamespaceConnectionRequest represents a request to delete a
    connection.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID."""
    connection_id: builtins.str
    """Connection ID."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_id", b"connection_id", "namespace_id", b"namespace_id"]) -> None: ...

global___DeleteNamespaceConnectionRequest = DeleteNamespaceConnectionRequest

@typing_extensions.final
class DeleteNamespaceConnectionResponse(google.protobuf.message.Message):
    """DeleteNamespaceConnectionResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DeleteNamespaceConnectionResponse = DeleteNamespaceConnectionResponse

@typing_extensions.final
class TestNamespaceConnectionRequest(google.protobuf.message.Message):
    """TestNamespaceConnectionRequest represents a request to test a connection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID."""
    connection_id: builtins.str
    """Connection ID."""
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        connection_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connection_id", b"connection_id", "namespace_id", b"namespace_id"]) -> None: ...

global___TestNamespaceConnectionRequest = TestNamespaceConnectionRequest

@typing_extensions.final
class TestNamespaceConnectionResponse(google.protobuf.message.Message):
    """TestNamespaceConnectionResponse is an empty response."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___TestNamespaceConnectionResponse = TestNamespaceConnectionResponse

@typing_extensions.final
class Integration(google.protobuf.message.Message):
    """Integration contains the parameters to create a connection between
    components and 3rd party apps.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Link(google.protobuf.message.Message):
        """Link contains the information to display an reference to an external URL."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TEXT_FIELD_NUMBER: builtins.int
        URL_FIELD_NUMBER: builtins.int
        text: builtins.str
        """Text contains the message to display."""
        url: builtins.str
        """URL contains the reference the link will redirect to."""
        def __init__(
            self,
            *,
            text: builtins.str = ...,
            url: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "url", b"url"]) -> None: ...

    @typing_extensions.final
    class OAuthConfig(google.protobuf.message.Message):
        """OAuthConfig contains the configuration parameters for fetching an access
        token via an OAuth 2.0 flow.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        AUTH_URL_FIELD_NUMBER: builtins.int
        ACCESS_URL_FIELD_NUMBER: builtins.int
        SCOPES_FIELD_NUMBER: builtins.int
        auth_url: builtins.str
        """The URL of the OAuth server to initiate the authentication and
        authorization process.
        """
        access_url: builtins.str
        """The URL of the OAuth server to exchange the authorization code for an
        access token.
        """
        @property
        def scopes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """A list of scopes that identify the resources that the connection will be
            able to access on the user's behalf.
            """
        def __init__(
            self,
            *,
            auth_url: builtins.str = ...,
            access_url: builtins.str = ...,
            scopes: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["access_url", b"access_url", "auth_url", b"auth_url", "scopes", b"scopes"]) -> None: ...

    @typing_extensions.final
    class SetupSchema(google.protobuf.message.Message):
        """SetupSchema defines the schema for a connection setup.
        This message is deprecated.
        """

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        METHOD_FIELD_NUMBER: builtins.int
        SCHEMA_FIELD_NUMBER: builtins.int
        method: global___Connection.Method.ValueType
        """The connection method, which will define the fields in the schema."""
        @property
        def schema(self) -> google.protobuf.struct_pb2.Struct:
            """The connection setup field definitions. Each integration will require
            different data to connect to the 3rd party app.
            """
        def __init__(
            self,
            *,
            method: global___Connection.Method.ValueType = ...,
            schema: google.protobuf.struct_pb2.Struct | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["schema", b"schema"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["method", b"method", "schema", b"schema"]) -> None: ...

    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    HELP_LINK_FIELD_NUMBER: builtins.int
    SETUP_SCHEMA_FIELD_NUMBER: builtins.int
    O_AUTH_CONFIG_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    SCHEMAS_FIELD_NUMBER: builtins.int
    uid: builtins.str
    """UUID-formatted unique identifier. It references a component definition."""
    id: builtins.str
    """Identifier of the integration, which references a component definition.
    Components with that definition ID will be able to use the connections
    produced by this integration.
    """
    title: builtins.str
    """Title, reflects the app name."""
    description: builtins.str
    """Short description of the integrated app."""
    vendor: builtins.str
    """Integrated app vendor name."""
    icon: builtins.str
    """Integration icon. This is a path that's relative to the root of
    the component implementation and that allows frontend applications to pull
    and locate the icons.
    See the `icon` field in the `ComponentDefinition` entity for more
    information.
    """
    @property
    def help_link(self) -> global___Integration.Link:
        """Reference to the vendor's documentation to expand the integration details."""
    @property
    def setup_schema(self) -> google.protobuf.struct_pb2.Struct:
        """The connection setup field definitions. Each integration will require
        different data to connect to the 3rd party app.
        """
    @property
    def o_auth_config(self) -> global___Integration.OAuthConfig:
        """Configuration parameters required for the OAuth setup flow. This field
        will be present only if the integration supports OAuth 2.0.
        """
    view: vdp.pipeline.v1beta.common_pb2.View.ValueType
    """View defines how the integration is presented. The following fields are
    only shown in the FULL view:
    - schemas
    - setupSchema
    - oAuthConfig
    """
    @property
    def schemas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Integration.SetupSchema]:
        """Schemas defines the supported schemas for the connection setup.
        We haven't found a case for a schema that changes on the connection method
        (components don't care about how the connection was built), so the schema
        will be provided in the setupSchema field and the OAuth support and
        configuration will be provided in oAuthConfig.
        """
    def __init__(
        self,
        *,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        vendor: builtins.str = ...,
        icon: builtins.str = ...,
        help_link: global___Integration.Link | None = ...,
        setup_schema: google.protobuf.struct_pb2.Struct | None = ...,
        o_auth_config: global___Integration.OAuthConfig | None = ...,
        view: vdp.pipeline.v1beta.common_pb2.View.ValueType = ...,
        schemas: collections.abc.Iterable[global___Integration.SetupSchema] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_help_link", b"_help_link", "_o_auth_config", b"_o_auth_config", "help_link", b"help_link", "o_auth_config", b"o_auth_config", "setup_schema", b"setup_schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_help_link", b"_help_link", "_o_auth_config", b"_o_auth_config", "description", b"description", "help_link", b"help_link", "icon", b"icon", "id", b"id", "o_auth_config", b"o_auth_config", "schemas", b"schemas", "setup_schema", b"setup_schema", "title", b"title", "uid", b"uid", "vendor", b"vendor", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_help_link", b"_help_link"]) -> typing_extensions.Literal["help_link"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_o_auth_config", b"_o_auth_config"]) -> typing_extensions.Literal["o_auth_config"] | None: ...

global___Integration = Integration

@typing_extensions.final
class ListPipelineIDsByConnectionIDRequest(google.protobuf.message.Message):
    """ListPipelineIDsByConnectionIDRequest represents a request to list the
    pipelines that reference a connection.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAMESPACE_ID_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    namespace_id: builtins.str
    """Namespace ID."""
    connection_id: builtins.str
    """Connection ID."""
    page_size: builtins.int
    """The maximum number of items to return. The default and cap values are 10 and 100, respectively."""
    page_token: builtins.str
    """Page token. By default, the first page will be returned."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter expression.
    The following filters are supported:
    - `q` (fuzzy search on pipeline ID)
    """
    def __init__(
        self,
        *,
        namespace_id: builtins.str = ...,
        connection_id: builtins.str = ...,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "connection_id", b"connection_id", "filter", b"filter", "namespace_id", b"namespace_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListPipelineIDsByConnectionIDRequest = ListPipelineIDsByConnectionIDRequest

@typing_extensions.final
class ListPipelineIDsByConnectionIDResponse(google.protobuf.message.Message):
    """ListPipelineIDsByConnectionIDResponse contains a paginated list of integrations."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIPELINE_IDS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def pipeline_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """A list of pipeline IDs matching the request parameters."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of items."""
    def __init__(
        self,
        *,
        pipeline_ids: collections.abc.Iterable[builtins.str] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "pipeline_ids", b"pipeline_ids", "total_size", b"total_size"]) -> None: ...

global___ListPipelineIDsByConnectionIDResponse = ListPipelineIDsByConnectionIDResponse

@typing_extensions.final
class ListIntegrationsRequest(google.protobuf.message.Message):
    """ListIntegrationsRequest represents a request to list the available
    integrations.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of items to return. The default and cap values are 10 and 100, respectively."""
    page_token: builtins.str
    """Page token. By default, the first page will be returned."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter expression.
    The following filters are supported:
    - `qIntegration` (fuzzy search on title or vendor)

    **Examples**:
    - List integrations where app name or vendor match `googl`: `q="googl"`.
    """
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...

global___ListIntegrationsRequest = ListIntegrationsRequest

@typing_extensions.final
class ListIntegrationsResponse(google.protobuf.message.Message):
    """ListIntegrationsResponse contains a paginated list of integrations."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def integrations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Integration]:
        """A list of integrations matching the request parameters."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of items."""
    def __init__(
        self,
        *,
        integrations: collections.abc.Iterable[global___Integration] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["integrations", b"integrations", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListIntegrationsResponse = ListIntegrationsResponse

@typing_extensions.final
class GetIntegrationRequest(google.protobuf.message.Message):
    """GetIntegrationRequest represents a request to view the details of an
    integration.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_ID_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    integration_id: builtins.str
    """Integration ID."""
    view: vdp.pipeline.v1beta.common_pb2.View.ValueType
    """View allows clients to specify the desired view in the response."""
    def __init__(
        self,
        *,
        integration_id: builtins.str = ...,
        view: vdp.pipeline.v1beta.common_pb2.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "integration_id", b"integration_id", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetIntegrationRequest = GetIntegrationRequest

@typing_extensions.final
class GetIntegrationResponse(google.protobuf.message.Message):
    """GetIntegrationResponse contains the requested integration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTEGRATION_FIELD_NUMBER: builtins.int
    @property
    def integration(self) -> global___Integration:
        """The requested integration."""
    def __init__(
        self,
        *,
        integration: global___Integration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["integration", b"integration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["integration", b"integration"]) -> None: ...

global___GetIntegrationResponse = GetIntegrationResponse



import argparse
import json
import pprint

import requests

from instill.utils.logger import Logger

parser = argparse.ArgumentParser()

parser.add_argument(
    "-i",
    "--input",
    help="inference input json",
    required=True,
)

args = parser.parse_args()

resp = requests.post("http://127.0.0.1:8000/", json=json.loads(args.input), timeout=600)

if resp.status_code == 200:
    Logger.i(f"[Instill] Outputs:\n{pprint.pformat(resp.json())}")
else:
    Logger.e(f"[Instill] Errors:\n{pprint.pformat(resp.text)}")



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import grpc
import grpc.aio
import typing
import vdp.pipeline.v1beta.pipeline_pb2

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class PipelinePrivateServiceStub:
    """PipelinePrivateService defines private methods to interact with Pipeline
    resources.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListPipelinesAdmin: grpc.UnaryUnaryMultiCallable[
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminRequest,
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminResponse,
    ]
    """List pipelines (admin only)

    This is a *private* method that allows admin users and internal clients to
    list *all* pipeline resources.
    """
    LookUpPipelineAdmin: grpc.UnaryUnaryMultiCallable[
        vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminRequest,
        vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminResponse,
    ]
    """Get a pipeline by UID (admin only)

    This is a *private* method that allows admin users to access any pipeline
    resource by its UID.
    """
    ListPipelineReleasesAdmin: grpc.UnaryUnaryMultiCallable[
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminRequest,
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminResponse,
    ]
    """List pipeline releases (admin only)

    This is a *private* method that allows admin users to list *all* pipeline
    releases.
    """

class PipelinePrivateServiceAsyncStub:
    """PipelinePrivateService defines private methods to interact with Pipeline
    resources.
    """

    ListPipelinesAdmin: grpc.aio.UnaryUnaryMultiCallable[
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminRequest,
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminResponse,
    ]
    """List pipelines (admin only)

    This is a *private* method that allows admin users and internal clients to
    list *all* pipeline resources.
    """
    LookUpPipelineAdmin: grpc.aio.UnaryUnaryMultiCallable[
        vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminRequest,
        vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminResponse,
    ]
    """Get a pipeline by UID (admin only)

    This is a *private* method that allows admin users to access any pipeline
    resource by its UID.
    """
    ListPipelineReleasesAdmin: grpc.aio.UnaryUnaryMultiCallable[
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminRequest,
        vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminResponse,
    ]
    """List pipeline releases (admin only)

    This is a *private* method that allows admin users to list *all* pipeline
    releases.
    """

class PipelinePrivateServiceServicer(metaclass=abc.ABCMeta):
    """PipelinePrivateService defines private methods to interact with Pipeline
    resources.
    """

    @abc.abstractmethod
    def ListPipelinesAdmin(
        self,
        request: vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminResponse, collections.abc.Awaitable[vdp.pipeline.v1beta.pipeline_pb2.ListPipelinesAdminResponse]]:
        """List pipelines (admin only)

        This is a *private* method that allows admin users and internal clients to
        list *all* pipeline resources.
        """
    @abc.abstractmethod
    def LookUpPipelineAdmin(
        self,
        request: vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminResponse, collections.abc.Awaitable[vdp.pipeline.v1beta.pipeline_pb2.LookUpPipelineAdminResponse]]:
        """Get a pipeline by UID (admin only)

        This is a *private* method that allows admin users to access any pipeline
        resource by its UID.
        """
    @abc.abstractmethod
    def ListPipelineReleasesAdmin(
        self,
        request: vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminResponse, collections.abc.Awaitable[vdp.pipeline.v1beta.pipeline_pb2.ListPipelineReleasesAdminResponse]]:
        """List pipeline releases (admin only)

        This is a *private* method that allows admin users to list *all* pipeline
        releases.
        """

def add_PipelinePrivateServiceServicer_to_server(servicer: PipelinePrivateServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import collections.abc
import core.mgmt.v1beta.mgmt_pb2
import grpc
import grpc.aio
import typing

_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore
    ...

class MgmtPrivateServiceStub:
    """Mgmt service responds to internal access"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ListUsersAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse,
    ]
    """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
    a ListUsersAdminResponse message.
    """
    GetUserAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse,
    ]
    """GetUserAdmin method receives a GetUserAdminRequest message and returns
    a GetUserAdminResponse message.
    """
    LookUpUserAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse,
    ]
    """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
    returns a LookUpUserAdminResponse
    """
    ListOrganizationsAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse,
    ]
    """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
    a ListOrganizationsAdminResponse message.
    """
    GetOrganizationAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse,
    ]
    """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
    a GetOrganizationAdminResponse message.
    """
    LookUpOrganizationAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse,
    ]
    """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
    returns a LookUpOrganizationAdminResponse
    """
    GetUserSubscriptionAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse,
    ]
    """GetUserSubscriptionAdmin"""
    GetOrganizationSubscriptionAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse,
    ]
    """GetOrganizationSubscriptionAdmin"""
    SubtractCreditAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminResponse,
    ]
    """Subtract Instill Credit from a user or organization account.

    This endpoint subtracts the specified amount of Instill Credit from an
    account. This is intended for processes on Instill Cloud that consume
    credit, such as the execution of pre-configured connectors.
    Note that if the remaining credit in the account is less than the
    requested amount, it will be subtracted anyways, leaving the account
    credit at zero. A ResourceExhausted error will be returned in this case.

    On Instill Core, this endpoint will return an Unimplemented status.
    """
    GetRemainingCreditAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminResponse,
    ]
    """Get the remaining Instill Credit by owner UID

    This endpoint fetches the remaining unexpired credit of a user or
    organization, referenced by UID.

    On Instill Core, this endpoint will return a 404 Not Found status.
    """
    CheckNamespaceAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminResponse,
    ]
    """Check if a namespace is in use

    Returns the availability of a namespace or, alternatively, the type of
    resource that is using it.
    """
    CheckNamespaceByUIDAdmin: grpc.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminResponse,
    ]
    """Check if a namespace is in use by UID

    Returns the availability of a namespace or, alternatively, the type of
    resource that is using it.
    """

class MgmtPrivateServiceAsyncStub:
    """Mgmt service responds to internal access"""

    ListUsersAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse,
    ]
    """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
    a ListUsersAdminResponse message.
    """
    GetUserAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse,
    ]
    """GetUserAdmin method receives a GetUserAdminRequest message and returns
    a GetUserAdminResponse message.
    """
    LookUpUserAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse,
    ]
    """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
    returns a LookUpUserAdminResponse
    """
    ListOrganizationsAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse,
    ]
    """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
    a ListOrganizationsAdminResponse message.
    """
    GetOrganizationAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse,
    ]
    """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
    a GetOrganizationAdminResponse message.
    """
    LookUpOrganizationAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse,
    ]
    """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
    returns a LookUpOrganizationAdminResponse
    """
    GetUserSubscriptionAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse,
    ]
    """GetUserSubscriptionAdmin"""
    GetOrganizationSubscriptionAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse,
    ]
    """GetOrganizationSubscriptionAdmin"""
    SubtractCreditAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminResponse,
    ]
    """Subtract Instill Credit from a user or organization account.

    This endpoint subtracts the specified amount of Instill Credit from an
    account. This is intended for processes on Instill Cloud that consume
    credit, such as the execution of pre-configured connectors.
    Note that if the remaining credit in the account is less than the
    requested amount, it will be subtracted anyways, leaving the account
    credit at zero. A ResourceExhausted error will be returned in this case.

    On Instill Core, this endpoint will return an Unimplemented status.
    """
    GetRemainingCreditAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminResponse,
    ]
    """Get the remaining Instill Credit by owner UID

    This endpoint fetches the remaining unexpired credit of a user or
    organization, referenced by UID.

    On Instill Core, this endpoint will return a 404 Not Found status.
    """
    CheckNamespaceAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminResponse,
    ]
    """Check if a namespace is in use

    Returns the availability of a namespace or, alternatively, the type of
    resource that is using it.
    """
    CheckNamespaceByUIDAdmin: grpc.aio.UnaryUnaryMultiCallable[
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminRequest,
        core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminResponse,
    ]
    """Check if a namespace is in use by UID

    Returns the availability of a namespace or, alternatively, the type of
    resource that is using it.
    """

class MgmtPrivateServiceServicer(metaclass=abc.ABCMeta):
    """Mgmt service responds to internal access"""

    @abc.abstractmethod
    def ListUsersAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListUsersAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListUsersAdminResponse]]:
        """ListUsersAdmin method receives a ListUsersAdminRequest message and returns
        a ListUsersAdminResponse message.
        """
    @abc.abstractmethod
    def GetUserAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetUserAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetUserAdminResponse]]:
        """GetUserAdmin method receives a GetUserAdminRequest message and returns
        a GetUserAdminResponse message.
        """
    @abc.abstractmethod
    def LookUpUserAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.LookUpUserAdminResponse]]:
        """LookUpUserAdmin method receives a LookUpUserAdminRequest message and
        returns a LookUpUserAdminResponse
        """
    @abc.abstractmethod
    def ListOrganizationsAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.ListOrganizationsAdminResponse]]:
        """ListOrganizationsAdmin method receives a ListOrganizationsAdminRequest message and returns
        a ListOrganizationsAdminResponse message.
        """
    @abc.abstractmethod
    def GetOrganizationAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationAdminResponse]]:
        """GetOrganizationAdmin method receives a GetOrganizationAdminRequest message and returns
        a GetOrganizationAdminResponse message.
        """
    @abc.abstractmethod
    def LookUpOrganizationAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.LookUpOrganizationAdminResponse]]:
        """LookUpOrganizationAdmin method receives a LookUpOrganizationAdminRequest message and
        returns a LookUpOrganizationAdminResponse
        """
    @abc.abstractmethod
    def GetUserSubscriptionAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetUserSubscriptionAdminResponse]]:
        """GetUserSubscriptionAdmin"""
    @abc.abstractmethod
    def GetOrganizationSubscriptionAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetOrganizationSubscriptionAdminResponse]]:
        """GetOrganizationSubscriptionAdmin"""
    @abc.abstractmethod
    def SubtractCreditAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.SubtractCreditAdminResponse]]:
        """Subtract Instill Credit from a user or organization account.

        This endpoint subtracts the specified amount of Instill Credit from an
        account. This is intended for processes on Instill Cloud that consume
        credit, such as the execution of pre-configured connectors.
        Note that if the remaining credit in the account is less than the
        requested amount, it will be subtracted anyways, leaving the account
        credit at zero. A ResourceExhausted error will be returned in this case.

        On Instill Core, this endpoint will return an Unimplemented status.
        """
    @abc.abstractmethod
    def GetRemainingCreditAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.GetRemainingCreditAdminResponse]]:
        """Get the remaining Instill Credit by owner UID

        This endpoint fetches the remaining unexpired credit of a user or
        organization, referenced by UID.

        On Instill Core, this endpoint will return a 404 Not Found status.
        """
    @abc.abstractmethod
    def CheckNamespaceAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.CheckNamespaceAdminResponse]]:
        """Check if a namespace is in use

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """
    @abc.abstractmethod
    def CheckNamespaceByUIDAdmin(
        self,
        request: core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminRequest,
        context: _ServicerContext,
    ) -> typing.Union[core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminResponse, collections.abc.Awaitable[core.mgmt.v1beta.mgmt_pb2.CheckNamespaceByUIDAdminResponse]]:
        """Check if a namespace is in use by UID

        Returns the availability of a namespace or, alternatively, the type of
        resource that is using it.
        """

def add_MgmtPrivateServiceServicer_to_server(servicer: MgmtPrivateServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



import os
from typing import Callable, Optional
from warnings import warn

from ray.serve import Deployment
from ray.serve import deployment as ray_deployment

from instill.helpers.const import (
    DEFAULT_AUTOSCALING_CONFIG,
    DEFAULT_MAX_ONGOING_REQUESTS,
    DEFAULT_MAX_QUEUED_REQUESTS,
    DEFAULT_RAY_ACTOR_OPTIONS,
    ENV_IS_TEST_MODEL,
    ENV_MEMORY,
    ENV_NUM_OF_CPUS,
    ENV_NUM_OF_GPUS,
    ENV_NUM_OF_MAX_REPLICAS,
    ENV_NUM_OF_MIN_REPLICAS,
    ENV_RAY_ACCELERATOR_TYPE,
    ENV_RAY_CUSTOM_RESOURCE,
    ENV_TOTAL_VRAM,
    RAM_MINIMUM_RESERVE,
    RAM_UPSCALE_FACTOR,
    VRAM_MINIMUM_RESERVE,
    VRAM_UPSCALE_FACTOR,
)
from instill.helpers.errors import ModelPathException
from instill.helpers.utils import get_dir_size


class InstillDeployable:
    def __init__(self, deployable: Deployment) -> None:
        self._deployment: Deployment = deployable
        self._autoscaling_config = DEFAULT_AUTOSCALING_CONFIG.copy()

        num_of_cpus = os.getenv(ENV_NUM_OF_CPUS)
        if num_of_cpus is not None and num_of_cpus != "":
            self._update_num_cpus(float(num_of_cpus))

        is_test_model = os.getenv(ENV_IS_TEST_MODEL)
        if is_test_model is not None and is_test_model.lower() == "true":
            self._update_num_cpus(float(0.001))
            self._update_downscale_delay(60)

        memory = os.getenv(ENV_MEMORY)
        if memory is not None and memory != "":
            self._update_memory(float(memory))

        num_of_gpus = os.getenv(ENV_NUM_OF_GPUS)
        vram = os.getenv(ENV_TOTAL_VRAM)
        if vram is not None and vram != "":
            self._update_num_gpus(self._determine_vram_usage(os.getcwd(), vram))
        elif num_of_gpus is not None and num_of_gpus != "":
            self._update_num_gpus(float(num_of_gpus))

        num_of_gpus = self._deployment.ray_actor_options.get(  # type: ignore
            "num_gpus", 0.001
        )

        accelerator_type = os.getenv(ENV_RAY_ACCELERATOR_TYPE)
        if accelerator_type is not None and accelerator_type != "":
            self._update_accelerator_type(accelerator_type)

        custom_resource = os.getenv(ENV_RAY_CUSTOM_RESOURCE)
        if custom_resource is not None and custom_resource != "":
            self._update_custom_resource(custom_resource, num_of_gpus)

        num_of_min_replicas = os.getenv(ENV_NUM_OF_MIN_REPLICAS)
        if num_of_min_replicas is not None and num_of_min_replicas != "":
            self._update_min_replicas(int(num_of_min_replicas))
        else:
            self._update_min_replicas(0)

        num_of_max_replicas = os.getenv(ENV_NUM_OF_MAX_REPLICAS)
        if num_of_max_replicas is not None and num_of_max_replicas != "":
            self._update_max_replicas(int(num_of_max_replicas))
        else:
            self._update_max_replicas(1)

    def _determine_vram_usage(self, model_path: str, total_vram: str):
        warn(
            "determine vram usage base on file size will soon be removed",
            PendingDeprecationWarning,
        )
        if total_vram == "":
            return 0.25
        if os.path.isfile(model_path):
            min_vram_usage = max(
                VRAM_MINIMUM_RESERVE,
                VRAM_UPSCALE_FACTOR
                * os.path.getsize(model_path)
                / (1024 * 1024 * 1024),
            )
            ratio = min_vram_usage / float(total_vram)
            if ratio > 1:
                warn(
                    "model projected vram usage is more than the GPU can handle, \
                    deployment might result in error state"
                )
                ratio = 1
            return ratio
        if os.path.isdir(model_path):
            min_vram_usage = max(
                VRAM_MINIMUM_RESERVE,
                VRAM_UPSCALE_FACTOR * get_dir_size(model_path) / (1024 * 1024 * 1024),
            )
            ratio = min_vram_usage / float(total_vram)
            if ratio > 1:
                warn(
                    "model projected vram usage is more than the GPU can handle, \
                    deployment might result in error state"
                )
                ratio = 1
            return ratio
        raise ModelPathException

    def _determine_ram_usage(self, model_path: str):
        warn(
            "determine ram usage base on file size will soon be removed",
            PendingDeprecationWarning,
        )
        if os.path.isfile(model_path):
            return max(
                RAM_MINIMUM_RESERVE * (1024 * 1024 * 1024),
                RAM_UPSCALE_FACTOR * os.path.getsize(model_path),
            )
        if os.path.isdir(model_path):
            return max(
                RAM_MINIMUM_RESERVE * (1024 * 1024 * 1024),
                RAM_UPSCALE_FACTOR * get_dir_size(model_path),
            )
        raise ModelPathException

    def _update_num_cpus(self, num_cpus: float):
        if self._deployment.ray_actor_options is not None:
            self._deployment.ray_actor_options.update({"num_cpus": num_cpus})

        return self

    def _update_memory(self, memory: float):
        if self._deployment.ray_actor_options is not None:
            self._deployment.ray_actor_options.update({"memory": memory})

        return self

    def _update_num_gpus(self, num_gpus: float):
        if self._deployment.ray_actor_options is not None:
            self._deployment.ray_actor_options.update({"num_gpus": num_gpus})

        return self

    def _update_accelerator_type(self, accelerator_type: str):
        if self._deployment.ray_actor_options is not None:
            self._deployment.ray_actor_options.update(
                {"accelerator_type": accelerator_type}
            )

        return self

    def _update_custom_resource(self, resource_name: str, ratio=0.001):
        if self._deployment.ray_actor_options is not None:
            self._deployment.ray_actor_options.update(
                {"resources": {resource_name: ratio}}
            )

        return self

    def _update_min_replicas(self, num_replicas: int):
        self._autoscaling_config["min_replicas"] = num_replicas
        self._deployment = self._deployment.options(
            autoscaling_config=self._autoscaling_config
        )

        return self

    def _update_max_replicas(self, num_replicas: int):
        self._autoscaling_config["max_replicas"] = num_replicas
        self._deployment = self._deployment.options(
            autoscaling_config=self._autoscaling_config
        )

        return self

    def _update_downscale_delay(self, downscale_delay_s: int):
        self._autoscaling_config["downscale_delay_s"] = downscale_delay_s

    def get_deployment_handle(self):
        return self._deployment.bind()


def instill_deployment(
    _func_or_class: Optional[Callable] = None,
) -> Callable[[Callable], InstillDeployable]:
    return ray_deployment(
        _func_or_class=_func_or_class,
        ray_actor_options=DEFAULT_RAY_ACTOR_OPTIONS,
        autoscaling_config=DEFAULT_AUTOSCALING_CONFIG,
        max_ongoing_requests=DEFAULT_MAX_ONGOING_REQUESTS,
        max_queued_requests=DEFAULT_MAX_QUEUED_REQUESTS,
    )



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: artifact/artifact/v1alpha/file_catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from artifact.artifact.v1alpha import artifact_pb2 as artifact_dot_artifact_dot_v1alpha_dot_artifact__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,artifact/artifact/v1alpha/file_catalog.proto\x12\x19\x61rtifact.artifact.v1alpha\x1a(artifact/artifact/v1alpha/artifact.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x8d\x01\n\x15GetFileCatalogRequest\x12!\n\x0cnamespace_id\x18\x01 \x01(\tR\x0bnamespaceId\x12\x1d\n\ncatalog_id\x18\x02 \x01(\tR\tcatalogId\x12\x17\n\x07\x66ile_id\x18\x03 \x01(\tR\x06\x66ileId\x12\x19\n\x08\x66ile_uid\x18\x04 \x01(\tR\x07\x66ileUid\"\x95\x0b\n\x16GetFileCatalogResponse\x12#\n\roriginal_data\x18\x01 \x01(\tR\x0coriginalData\x12V\n\x08metadata\x18\x02 \x01(\x0b\x32:.artifact.artifact.v1alpha.GetFileCatalogResponse.MetadataR\x08metadata\x12J\n\x04text\x18\x03 \x01(\x0b\x32\x36.artifact.artifact.v1alpha.GetFileCatalogResponse.TextR\x04text\x12O\n\x06\x63hunks\x18\x04 \x03(\x0b\x32\x37.artifact.artifact.v1alpha.GetFileCatalogResponse.ChunkR\x06\x63hunks\x1a\xc1\x02\n\x08Metadata\x12\x19\n\x08\x66ile_uid\x18\x01 \x01(\tR\x07\x66ileUid\x12\x17\n\x07\x66ile_id\x18\x02 \x01(\tR\x06\x66ileId\x12@\n\tfile_type\x18\x03 \x01(\x0e\x32#.artifact.artifact.v1alpha.FileTypeR\x08\x66ileType\x12\x1b\n\tfile_size\x18\x04 \x01(\x03R\x08\x66ileSize\x12\x44\n\x10\x66ile_upload_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0e\x66ileUploadTime\x12\\\n\x13\x66ile_process_status\x18\x06 \x01(\x0e\x32,.artifact.artifact.v1alpha.FileProcessStatusR\x11\x66ileProcessStatus\x1a\xc3\x02\n\x04Text\x12!\n\x0cpipeline_ids\x18\x01 \x03(\tR\x0bpipelineIds\x12/\n\x13transformed_content\x18\x02 \x01(\tR\x12transformedContent\x12\x41\n\x1dtransformed_content_chunk_num\x18\x03 \x01(\x05R\x1atransformedContentChunkNum\x12\x41\n\x1dtransformed_content_token_num\x18\x04 \x01(\x05R\x1atransformedContentTokenNum\x12\x61\n\x1ftransformed_content_update_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x1ctransformedContentUpdateTime\x1a\xd6\x02\n\x05\x43hunk\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x12O\n\x04type\x18\x02 \x01(\x0e\x32;.artifact.artifact.v1alpha.GetFileCatalogResponse.ChunkTypeR\x04type\x12\x1b\n\tstart_pos\x18\x03 \x01(\x05R\x08startPos\x12\x17\n\x07\x65nd_pos\x18\x04 \x01(\x05R\x06\x65ndPos\x12\x18\n\x07\x63ontent\x18\x05 \x01(\tR\x07\x63ontent\x12\x1d\n\ntokens_num\x18\x06 \x01(\x05R\ttokensNum\x12\x1c\n\tembedding\x18\x07 \x03(\x02R\tembedding\x12;\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ncreateTime\x12 \n\x0bretrievable\x18\t \x01(\x08R\x0bretrievable\"~\n\tChunkType\x12\x1a\n\x16\x43HUNK_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x43HUNK_TYPE_TEXT\x10\x01\x12\x14\n\x10\x43HUNK_TYPE_IMAGE\x10\x02\x12\x14\n\x10\x43HUNK_TYPE_AUDIO\x10\x03\x12\x14\n\x10\x43HUNK_TYPE_VIDEO\x10\x04\x42\x84\x02\n\x1d\x63om.artifact.artifact.v1alphaB\x10\x46ileCatalogProtoP\x01ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\xa2\x02\x03\x41\x41X\xaa\x02\x19\x41rtifact.Artifact.V1alpha\xca\x02\x19\x41rtifact\\Artifact\\V1alpha\xe2\x02%Artifact\\Artifact\\V1alpha\\GPBMetadata\xea\x02\x1b\x41rtifact::Artifact::V1alphab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'artifact.artifact.v1alpha.file_catalog_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.artifact.artifact.v1alphaB\020FileCatalogProtoP\001ZKgithub.com/instill-ai/protogen-go/artifact/artifact/v1alpha;artifactv1alpha\242\002\003AAX\252\002\031Artifact.Artifact.V1alpha\312\002\031Artifact\\Artifact\\V1alpha\342\002%Artifact\\Artifact\\V1alpha\\GPBMetadata\352\002\033Artifact::Artifact::V1alpha'
  _globals['_GETFILECATALOGREQUEST']._serialized_start=151
  _globals['_GETFILECATALOGREQUEST']._serialized_end=292
  _globals['_GETFILECATALOGRESPONSE']._serialized_start=295
  _globals['_GETFILECATALOGRESPONSE']._serialized_end=1724
  _globals['_GETFILECATALOGRESPONSE_METADATA']._serialized_start=604
  _globals['_GETFILECATALOGRESPONSE_METADATA']._serialized_end=925
  _globals['_GETFILECATALOGRESPONSE_TEXT']._serialized_start=928
  _globals['_GETFILECATALOGRESPONSE_TEXT']._serialized_end=1251
  _globals['_GETFILECATALOGRESPONSE_CHUNK']._serialized_start=1254
  _globals['_GETFILECATALOGRESPONSE_CHUNK']._serialized_end=1596
  _globals['_GETFILECATALOGRESPONSE_CHUNKTYPE']._serialized_start=1598
  _globals['_GETFILECATALOGRESPONSE_CHUNKTYPE']._serialized_end=1724
# @@protoc_insertion_point(module_scope)



# type: ignore
# you can find a list of supported task in the helpers module
from instill.helpers import (
    construct_task_chat_output,
    parse_task_chat_to_multimodal_chat_input,
)
from instill.helpers.ray_config import InstillDeployable, instill_deployment


@instill_deployment
class ModelName:
    """Custom model implementation"""

    def __init__(self):
        """Load model into memory"""
        # self.pipeline = pipeline(
        #     "text-generation",
        #     model="tinyllama",
        #     torch_dtype=torch.float16,
        #     device_map="cuda:0",
        # )

    async def __call__(self, request):
        """Run inference logic"""

        # parse request into conversation chat input

        # conversation_inputs = await parse_task_chat_to_chat_input(request=request)

        # finish_reasons = []
        # indexes = []
        # created = []
        # messages = []
        # for i, inp in enumerate(conversation_inputs):
        #     prompt = self.pipeline.tokenizer.apply_chat_template(
        #         inp.messages,
        #         tokenize=False,
        #         add_generation_prompt=True,
        #     )

        #     # inference
        #     sequences = self.pipeline(
        #         prompt,
        #         max_new_tokens=inp.max_tokens,
        #         do_sample=True,
        #         temperature=inp.temperature,
        #         top_p=inp.top_p,
        #     )

        #     output = sequences[0]["generated_text"].split("<|assistant|>\n")[-1].strip()

        #     messages.append([{"content": output, "role": "assistant"}])
        #     finish_reasons.append(["length"])
        #     indexes.append([i])
        #     created.append([int(time.time())])

        # construct chat output

        # return construct_task_chat_output(
        #     request=request,
        #     finish_reasons=finish_reasons,
        #     indexes=indexes,
        #     messages=messages,
        #     created_timestamps=created,
        # )


# define model deployment entrypoint
entrypoint = InstillDeployable(ModelName).get_deployment_handle()



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import sys
import typing
import vdp.pipeline.v1beta.common_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ConnectorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ConnectorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ConnectorType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONNECTOR_TYPE_UNSPECIFIED: _ConnectorType.ValueType  # 0
    """Unspecified."""
    CONNECTOR_TYPE_AI: _ConnectorType.ValueType  # 3
    """AI connector."""
    CONNECTOR_TYPE_DATA: _ConnectorType.ValueType  # 5
    """Data connector."""
    CONNECTOR_TYPE_OPERATOR: _ConnectorType.ValueType  # 6
    """Operator connector."""
    CONNECTOR_TYPE_APPLICATION: _ConnectorType.ValueType  # 7
    """Application connector."""
    CONNECTOR_TYPE_GENERIC: _ConnectorType.ValueType  # 8
    """Generic."""

class ConnectorType(_ConnectorType, metaclass=_ConnectorTypeEnumTypeWrapper):
    """ConnectorType defines the connector type based on its task features."""

CONNECTOR_TYPE_UNSPECIFIED: ConnectorType.ValueType  # 0
"""Unspecified."""
CONNECTOR_TYPE_AI: ConnectorType.ValueType  # 3
"""AI connector."""
CONNECTOR_TYPE_DATA: ConnectorType.ValueType  # 5
"""Data connector."""
CONNECTOR_TYPE_OPERATOR: ConnectorType.ValueType  # 6
"""Operator connector."""
CONNECTOR_TYPE_APPLICATION: ConnectorType.ValueType  # 7
"""Application connector."""
CONNECTOR_TYPE_GENERIC: ConnectorType.ValueType  # 8
"""Generic."""
global___ConnectorType = ConnectorType

@typing_extensions.final
class ComponentDefinition(google.protobuf.message.Message):
    """/////////////////////////////////////////////////////////////////////
    Domain types
    /////////////////////////////////////////////////////////////////////

    ComponentDefinition describes a certain type of Component.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _View:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ViewEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ComponentDefinition._View.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIEW_UNSPECIFIED: ComponentDefinition._View.ValueType  # 0
        """Unspecified, equivalent to BASIC."""
        VIEW_BASIC: ComponentDefinition._View.ValueType  # 1
        """Default view, only includes basic information (removes the `spec`
        field).
        """
        VIEW_FULL: ComponentDefinition._View.ValueType  # 2
        """Full representation."""

    class View(_View, metaclass=_ViewEnumTypeWrapper):
        """View defines how a component definition is presented."""

    VIEW_UNSPECIFIED: ComponentDefinition.View.ValueType  # 0
    """Unspecified, equivalent to BASIC."""
    VIEW_BASIC: ComponentDefinition.View.ValueType  # 1
    """Default view, only includes basic information (removes the `spec`
    field).
    """
    VIEW_FULL: ComponentDefinition.View.ValueType  # 2
    """Full representation."""

    class _ReleaseStage:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ReleaseStageEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ComponentDefinition._ReleaseStage.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        RELEASE_STAGE_UNSPECIFIED: ComponentDefinition._ReleaseStage.ValueType  # 0
        """Unspecified."""
        RELEASE_STAGE_OPEN_FOR_CONTRIBUTION: ComponentDefinition._ReleaseStage.ValueType  # 1
        """This component is unimplemented and community contributions are welcome
        for this component.

        It is recommended that the major and minor versions for definitions at
        this release stage is kept at 0, e.g., `0.0.1`, `0.0.4`, etc.
        """
        RELEASE_STAGE_COMING_SOON: ComponentDefinition._ReleaseStage.ValueType  # 2
        """The implementation of this component is planned and will be tackled by
        the Instill AI team.

        It is recommended that the major and minor versions for definitions at
        this release stage is kept at 0, e.g., `0.0.1`, `0.0.4`, etc.
        """
        RELEASE_STAGE_ALPHA: ComponentDefinition._ReleaseStage.ValueType  # 3
        """Initial implementation intended to gather feedback and issues from early
        adopters. Alpha releases are discouraged for production use cases.

        The `version` field in the definition must have `alpha` as its first
        pre-release identifier, e.g., `0.1.0-alpha`, `0.1.3-alpha.1`.
        """
        RELEASE_STAGE_BETA: ComponentDefinition._ReleaseStage.ValueType  # 4
        """The component has reached stability and no backwards incompatible
        changes are expected. Before reaching general availability, it should be
        validated by a broader group of users. Some fixes might be added during
        this process.

        The `version` field in the definition must have `beta` as its first
        pre-release identifier, e.g., `0.1.0-beta`, `0.1.3-beta.1`.
        """
        RELEASE_STAGE_GA: ComponentDefinition._ReleaseStage.ValueType  # 5
        """Generally available - ready for use in production and fully supported by
        Instill AI.
        """

    class ReleaseStage(_ReleaseStage, metaclass=_ReleaseStageEnumTypeWrapper):
        """ReleaseStage defines the release stage of a component. This is used to
        group components with the same pre-relase groups (e.g. `0.1.0-beta`,
        `0.1.0-beta.1` -> `RELEASE_STAGE_BETA`) and to include other "in progress"
        (i.e. coming soon, open for contributions) stages that may not be relevant
        within semantic versioning.
        See the documentation of each value for potential constraints between
        `version` and `release_stage` fields.`
        """

    RELEASE_STAGE_UNSPECIFIED: ComponentDefinition.ReleaseStage.ValueType  # 0
    """Unspecified."""
    RELEASE_STAGE_OPEN_FOR_CONTRIBUTION: ComponentDefinition.ReleaseStage.ValueType  # 1
    """This component is unimplemented and community contributions are welcome
    for this component.

    It is recommended that the major and minor versions for definitions at
    this release stage is kept at 0, e.g., `0.0.1`, `0.0.4`, etc.
    """
    RELEASE_STAGE_COMING_SOON: ComponentDefinition.ReleaseStage.ValueType  # 2
    """The implementation of this component is planned and will be tackled by
    the Instill AI team.

    It is recommended that the major and minor versions for definitions at
    this release stage is kept at 0, e.g., `0.0.1`, `0.0.4`, etc.
    """
    RELEASE_STAGE_ALPHA: ComponentDefinition.ReleaseStage.ValueType  # 3
    """Initial implementation intended to gather feedback and issues from early
    adopters. Alpha releases are discouraged for production use cases.

    The `version` field in the definition must have `alpha` as its first
    pre-release identifier, e.g., `0.1.0-alpha`, `0.1.3-alpha.1`.
    """
    RELEASE_STAGE_BETA: ComponentDefinition.ReleaseStage.ValueType  # 4
    """The component has reached stability and no backwards incompatible
    changes are expected. Before reaching general availability, it should be
    validated by a broader group of users. Some fixes might be added during
    this process.

    The `version` field in the definition must have `beta` as its first
    pre-release identifier, e.g., `0.1.0-beta`, `0.1.3-beta.1`.
    """
    RELEASE_STAGE_GA: ComponentDefinition.ReleaseStage.ValueType  # 5
    """Generally available - ready for use in production and fully supported by
    Instill AI.
    """

    @typing_extensions.final
    class Spec(google.protobuf.message.Message):
        """Spec represents a specification data model."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        @typing_extensions.final
        class DataSpecificationsEntry(google.protobuf.message.Message):
            DESCRIPTOR: google.protobuf.descriptor.Descriptor

            KEY_FIELD_NUMBER: builtins.int
            VALUE_FIELD_NUMBER: builtins.int
            key: builtins.str
            @property
            def value(self) -> global___DataSpecification: ...
            def __init__(
                self,
                *,
                key: builtins.str = ...,
                value: global___DataSpecification | None = ...,
            ) -> None: ...
            def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
            def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

        COMPONENT_SPECIFICATION_FIELD_NUMBER: builtins.int
        DATA_SPECIFICATIONS_FIELD_NUMBER: builtins.int
        @property
        def component_specification(self) -> google.protobuf.struct_pb2.Struct:
            """Component specification."""
        @property
        def data_specifications(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DataSpecification]:
            """Data specifications.
            The key represents the task, and the value is the corresponding data_specification.
            """
        def __init__(
            self,
            *,
            component_specification: google.protobuf.struct_pb2.Struct | None = ...,
            data_specifications: collections.abc.Mapping[builtins.str, global___DataSpecification] | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification", "data_specifications", b"data_specifications"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DOCUMENTATION_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TOMBSTONE_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    VENDOR_ATTRIBUTES_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RELEASE_STAGE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the component definition, defined by its ID.
    - Format: `component-definitions/{id}`
    """
    uid: builtins.str
    """Component definition UUID."""
    id: builtins.str
    """Component definition resource ID (used in `name` as the last segment). This
    conforms to RFC-1034, which restricts to letters, numbers, and hyphen,
    with the first character a letter, the last a letter or a number, and a 63
    character maximum.
    """
    title: builtins.str
    """Component definition title."""
    documentation_url: builtins.str
    """Component definition documentation URL."""
    icon: builtins.str
    """Component definition icon. This is a path that's relative to the root of
    the component implementation (see `source_url`) and that allows
    frontend applications to pull and locate the icons.
    """
    @property
    def spec(self) -> global___ComponentDefinition.Spec:
        """Component definition specification."""
    type: vdp.pipeline.v1beta.common_pb2.ComponentType.ValueType
    """Component definition type."""
    tombstone: builtins.bool
    """Component definition tombstone. If true, this configuration is permanently
    off. Otherwise, the configuration is active.
    """
    public: builtins.bool
    """The public flag determines whether this connector definition is available
    to all workspaces.
    """
    custom: builtins.bool
    """Component definition custom flag, i.e., whether this is a custom
    component definition.
    """
    vendor: builtins.str
    """Component definition vendor name."""
    @property
    def vendor_attributes(self) -> google.protobuf.struct_pb2.Struct:
        """Vendor-specific attributes."""
    source_url: builtins.str
    """Source code URL. This points to the source code where the component is
    implemented.
    """
    version: builtins.str
    """Component definition version. This is a string that fulfills the SemVer
    specification (e.g. `1.0.0-beta`).
    """
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[vdp.pipeline.v1beta.common_pb2.ComponentTask]:
        """List of tasks that can be executed by the component."""
    description: builtins.str
    """Short description of the component."""
    release_stage: global___ComponentDefinition.ReleaseStage.ValueType
    """Release stage."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        title: builtins.str = ...,
        documentation_url: builtins.str = ...,
        icon: builtins.str = ...,
        spec: global___ComponentDefinition.Spec | None = ...,
        type: vdp.pipeline.v1beta.common_pb2.ComponentType.ValueType = ...,
        tombstone: builtins.bool = ...,
        public: builtins.bool = ...,
        custom: builtins.bool = ...,
        vendor: builtins.str = ...,
        vendor_attributes: google.protobuf.struct_pb2.Struct | None = ...,
        source_url: builtins.str = ...,
        version: builtins.str = ...,
        tasks: collections.abc.Iterable[vdp.pipeline.v1beta.common_pb2.ComponentTask] | None = ...,
        description: builtins.str = ...,
        release_stage: global___ComponentDefinition.ReleaseStage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec", "vendor_attributes", b"vendor_attributes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom", b"custom", "description", b"description", "documentation_url", b"documentation_url", "icon", b"icon", "id", b"id", "name", b"name", "public", b"public", "release_stage", b"release_stage", "source_url", b"source_url", "spec", b"spec", "tasks", b"tasks", "title", b"title", "tombstone", b"tombstone", "type", b"type", "uid", b"uid", "vendor", b"vendor", "vendor_attributes", b"vendor_attributes", "version", b"version"]) -> None: ...

global___ComponentDefinition = ComponentDefinition

@typing_extensions.final
class DataSpecification(google.protobuf.message.Message):
    """DataSpecification describes the JSON schema of component input and output."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    @property
    def input(self) -> google.protobuf.struct_pb2.Struct:
        """JSON schema describing the component input data."""
    @property
    def output(self) -> google.protobuf.struct_pb2.Struct:
        """JSON schema describing the component output data."""
    def __init__(
        self,
        *,
        input: google.protobuf.struct_pb2.Struct | None = ...,
        output: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["input", b"input", "output", b"output"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["input", b"input", "output", b"output"]) -> None: ...

global___DataSpecification = DataSpecification

@typing_extensions.final
class ConnectorSpec(google.protobuf.message.Message):
    """ConnectorSpec represents a specification data model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DataSpecificationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DataSpecification: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DataSpecification | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMPONENT_SPECIFICATION_FIELD_NUMBER: builtins.int
    DATA_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    @property
    def component_specification(self) -> google.protobuf.struct_pb2.Struct:
        """Component specification."""
    @property
    def data_specifications(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DataSpecification]:
        """Data specifications.
        The key represents the task, and the value is the corresponding data_specification.
        """
    def __init__(
        self,
        *,
        component_specification: google.protobuf.struct_pb2.Struct | None = ...,
        data_specifications: collections.abc.Mapping[builtins.str, global___DataSpecification] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification", "data_specifications", b"data_specifications"]) -> None: ...

global___ConnectorSpec = ConnectorSpec

@typing_extensions.final
class ConnectorDefinition(google.protobuf.message.Message):
    """A Connector is a type of pipeline component that queries, processes or sends
    the ingested unstructured data to a service or app. Users need to configure
    their connectors (e.g. by providing an API token to a remote service). A
    ConnectorDefinition describes a certain type of Connector.

    For more information, see
    [Component](https://www.instill.tech/docs/component/introduction)
    in the official documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DOCUMENTATION_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    TOMBSTONE_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    VENDOR_FIELD_NUMBER: builtins.int
    VENDOR_ATTRIBUTES_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RELEASE_STAGE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the connector definition, defined by its ID.
    - Format: `connector-definitions/{id}
    """
    uid: builtins.str
    """Connector definition UUID."""
    id: builtins.str
    """Connector definition resource ID (used in `name` as the last segment). This
    conforms to RFC-1034, which restricts to letters, numbers, and hyphen,
    with the first character a letter, the last a letter or a number, and a 63
    character maximum.
    """
    title: builtins.str
    """Connector definition title."""
    documentation_url: builtins.str
    """Connector definition documentation URL."""
    icon: builtins.str
    """Connector definition icon. This is a path that's relative to the root of
    the connector implementation (see `source_url`) and that allows clients
    frontend applications to pull and locate the icons.
    """
    @property
    def spec(self) -> global___ConnectorSpec:
        """Connector definition specification."""
    type: global___ConnectorType.ValueType
    """Connector definition type."""
    tombstone: builtins.bool
    """Connector definition tombstone. If true, this configuration is permanently
    off. Otherwise, the configuration is active.
    """
    public: builtins.bool
    """The public flag determines whether this connector definition is available
    to all workspaces.
    """
    custom: builtins.bool
    """Connector definition custom flag, i.e., whether this is a custom
    connector definition.
    """
    vendor: builtins.str
    """Connector definition vendor name."""
    @property
    def vendor_attributes(self) -> google.protobuf.struct_pb2.Struct:
        """Vendor-specific attributes."""
    source_url: builtins.str
    """Source code URL. This points to the source code where the connector is
    implemented.
    """
    version: builtins.str
    """Connector definition version. This is a string that fulfills the SemVer
    specification (e.g. `1.0.0-beta`).
    """
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[vdp.pipeline.v1beta.common_pb2.ComponentTask]:
        """List of tasks that can be executed by the connector."""
    description: builtins.str
    """Short description of the connector."""
    release_stage: global___ComponentDefinition.ReleaseStage.ValueType
    """Release stage."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        title: builtins.str = ...,
        documentation_url: builtins.str = ...,
        icon: builtins.str = ...,
        spec: global___ConnectorSpec | None = ...,
        type: global___ConnectorType.ValueType = ...,
        tombstone: builtins.bool = ...,
        public: builtins.bool = ...,
        custom: builtins.bool = ...,
        vendor: builtins.str = ...,
        vendor_attributes: google.protobuf.struct_pb2.Struct | None = ...,
        source_url: builtins.str = ...,
        version: builtins.str = ...,
        tasks: collections.abc.Iterable[vdp.pipeline.v1beta.common_pb2.ComponentTask] | None = ...,
        description: builtins.str = ...,
        release_stage: global___ComponentDefinition.ReleaseStage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec", "vendor_attributes", b"vendor_attributes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom", b"custom", "description", b"description", "documentation_url", b"documentation_url", "icon", b"icon", "id", b"id", "name", b"name", "public", b"public", "release_stage", b"release_stage", "source_url", b"source_url", "spec", b"spec", "tasks", b"tasks", "title", b"title", "tombstone", b"tombstone", "type", b"type", "uid", b"uid", "vendor", b"vendor", "vendor_attributes", b"vendor_attributes", "version", b"version"]) -> None: ...

global___ConnectorDefinition = ConnectorDefinition

@typing_extensions.final
class OperatorSpec(google.protobuf.message.Message):
    """OperatorSpec represents a specification data model."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class DataSpecificationsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___DataSpecification: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___DataSpecification | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMPONENT_SPECIFICATION_FIELD_NUMBER: builtins.int
    DATA_SPECIFICATIONS_FIELD_NUMBER: builtins.int
    @property
    def component_specification(self) -> google.protobuf.struct_pb2.Struct:
        """Component specification."""
    @property
    def data_specifications(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___DataSpecification]:
        """Data specifications.
        The key represents the task, and the value is the corresponding data_specification.
        """
    def __init__(
        self,
        *,
        component_specification: google.protobuf.struct_pb2.Struct | None = ...,
        data_specifications: collections.abc.Mapping[builtins.str, global___DataSpecification] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_specification", b"component_specification", "data_specifications", b"data_specifications"]) -> None: ...

global___OperatorSpec = OperatorSpec

@typing_extensions.final
class OperatorDefinition(google.protobuf.message.Message):
    """An Operator is a type of pipeline component that performs data injection and
    manipulation. OperatorDefinition describes a certain type of operator.

    For more information, see
    [Component](https://www.instill.tech/docs/component/introduction)
    in the official documentation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DOCUMENTATION_URL_FIELD_NUMBER: builtins.int
    ICON_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    TOMBSTONE_FIELD_NUMBER: builtins.int
    PUBLIC_FIELD_NUMBER: builtins.int
    CUSTOM_FIELD_NUMBER: builtins.int
    SOURCE_URL_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RELEASE_STAGE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The name of the operator definition.
    - Format: `operator-definitions/*`
    """
    uid: builtins.str
    """Operator definition UUID."""
    id: builtins.str
    """Operator definition resource ID (used in `name` as the last segment).
    This conforms to RFC-1034, which restricts to letters, numbers, and
    hyphen, with the first character a letter, the last a letter or a number,
    and a 63 character maximum.
    """
    title: builtins.str
    """Operator definition title."""
    documentation_url: builtins.str
    """Operator definition documentation URL."""
    icon: builtins.str
    """Operator definition icon. This is a path that's relative to the root of
    the operator implementation (see `source_url`) and that allows clients
    frontend applications to pull and locate the icons.
    """
    @property
    def spec(self) -> global___OperatorSpec:
        """Operator definition specification."""
    tombstone: builtins.bool
    """Operator definition tombstone. If true, this configuration is permanently
    off. Otherwise, the configuration is active.
    """
    public: builtins.bool
    """The public flag determines whether this operator definition is available
    to all workspaces.
    """
    custom: builtins.bool
    """The custom flag determines whether this is a custom operator definition."""
    source_url: builtins.str
    """Source code URL. This points to the source code where the operator is
    implemented.
    """
    version: builtins.str
    """Operator definition version. This is a string that fulfills the SemVer
    specification (e.g. `1.0.0-beta`).
    """
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[vdp.pipeline.v1beta.common_pb2.ComponentTask]:
        """List of tasks that can be executed by the operator."""
    description: builtins.str
    """Short description of the operator."""
    release_stage: global___ComponentDefinition.ReleaseStage.ValueType
    """Release stage."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        uid: builtins.str = ...,
        id: builtins.str = ...,
        title: builtins.str = ...,
        documentation_url: builtins.str = ...,
        icon: builtins.str = ...,
        spec: global___OperatorSpec | None = ...,
        tombstone: builtins.bool = ...,
        public: builtins.bool = ...,
        custom: builtins.bool = ...,
        source_url: builtins.str = ...,
        version: builtins.str = ...,
        tasks: collections.abc.Iterable[vdp.pipeline.v1beta.common_pb2.ComponentTask] | None = ...,
        description: builtins.str = ...,
        release_stage: global___ComponentDefinition.ReleaseStage.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["custom", b"custom", "description", b"description", "documentation_url", b"documentation_url", "icon", b"icon", "id", b"id", "name", b"name", "public", b"public", "release_stage", b"release_stage", "source_url", b"source_url", "spec", b"spec", "tasks", b"tasks", "title", b"title", "tombstone", b"tombstone", "uid", b"uid", "version", b"version"]) -> None: ...

global___OperatorDefinition = OperatorDefinition

@typing_extensions.final
class ListComponentDefinitionsRequest(google.protobuf.message.Message):
    """/////////////////////////////////////////////////////////////////////
    API messages
    /////////////////////////////////////////////////////////////////////

    ListComponentDefinitionsRequest represents a request to list component
    definitions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of component definitions to return. If this parameter
    is unspecified, at most 10 definitions will be returned. The cap value for
    this parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    view: global___ComponentDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `component_type="COMPONENT_TYPE_AI"`.
    - Example: `tasks:"TASK_TEXT_GENERATION"`.
    """
    page: builtins.int
    """Page number."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        view: global___ComponentDefinition.View.ValueType | None = ...,
        filter: builtins.str | None = ...,
        page: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page", b"_page", "_page_size", b"_page_size", "_view", b"_view", "filter", b"filter", "page", b"page", "page_size", b"page_size", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page", b"_page", "_page_size", b"_page_size", "_view", b"_view", "filter", b"filter", "page", b"page", "page_size", b"page_size", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page", b"_page"]) -> typing_extensions.Literal["page"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListComponentDefinitionsRequest = ListComponentDefinitionsRequest

@typing_extensions.final
class ListComponentDefinitionsResponse(google.protobuf.message.Message):
    """ListComponentDefinitionsResponse contains a list of component definitions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMPONENT_DEFINITIONS_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_FIELD_NUMBER: builtins.int
    @property
    def component_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComponentDefinition]:
        """A list of component definition resources."""
    total_size: builtins.int
    """Total number of component definitions."""
    page_size: builtins.int
    """The requested page size."""
    page: builtins.int
    """The requested page offset."""
    def __init__(
        self,
        *,
        component_definitions: collections.abc.Iterable[global___ComponentDefinition] | None = ...,
        total_size: builtins.int = ...,
        page_size: builtins.int = ...,
        page: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["component_definitions", b"component_definitions", "page", b"page", "page_size", b"page_size", "total_size", b"total_size"]) -> None: ...

global___ListComponentDefinitionsResponse = ListComponentDefinitionsResponse

@typing_extensions.final
class ListConnectorDefinitionsRequest(google.protobuf.message.Message):
    """ListConnectorDefinitionsRequest represents a request to list connector
    definitions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of connector definitions to return. If this parameter
    is unspecified, at most 10 definitions will be returned. The cap value for
    this parameter is 100 (i.e. any value above that will be coerced to 100).
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    view: global___ComponentDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
        view: global___ComponentDefinition.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListConnectorDefinitionsRequest = ListConnectorDefinitionsRequest

@typing_extensions.final
class ListConnectorDefinitionsResponse(google.protobuf.message.Message):
    """ListConnectorDefinitionsResponse contains a list of connector definitions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_DEFINITIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def connector_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConnectorDefinition]:
        """A list of connector definition resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of connector definitions."""
    def __init__(
        self,
        *,
        connector_definitions: collections.abc.Iterable[global___ConnectorDefinition] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_definitions", b"connector_definitions", "next_page_token", b"next_page_token", "total_size", b"total_size"]) -> None: ...

global___ListConnectorDefinitionsResponse = ListConnectorDefinitionsResponse

@typing_extensions.final
class GetConnectorDefinitionRequest(google.protobuf.message.Message):
    """GetConnectorDefinitionRequest represents a request to fetch the details of a
    connector definition.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the connector definition, which allows its access by ID.
    - Format: `connector-definitions/{id}`.
    """
    view: global___ComponentDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___ComponentDefinition.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetConnectorDefinitionRequest = GetConnectorDefinitionRequest

@typing_extensions.final
class GetConnectorDefinitionResponse(google.protobuf.message.Message):
    """GetConnectorDefinitionResponse contains the requested connector definition."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONNECTOR_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def connector_definition(self) -> global___ConnectorDefinition:
        """The connector definition resource."""
    def __init__(
        self,
        *,
        connector_definition: global___ConnectorDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["connector_definition", b"connector_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["connector_definition", b"connector_definition"]) -> None: ...

global___GetConnectorDefinitionResponse = GetConnectorDefinitionResponse

@typing_extensions.final
class ListOperatorDefinitionsRequest(google.protobuf.message.Message):
    """ListOperatorDefinitionsRequest represents a request to list operator
    definitions.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """The maximum number of OperatorDefinitions to return. The
    service may return fewer than this value. If unspecified, at most 10
    OperatorDefinitions will be returned. The maximum value is 100;
    values above 100 will be coerced to 100.
    """
    page_token: builtins.str
    """Page token."""
    filter: builtins.str
    """Filter can hold an [AIP-160](https://google.aip.dev/160)-compliant filter
    expression.
    - Example: `create_time>timestamp("2000-06-19T23:31:08.657Z")`.
    """
    view: global___ComponentDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        page_size: builtins.int | None = ...,
        page_token: builtins.str | None = ...,
        filter: builtins.str | None = ...,
        view: global___ComponentDefinition.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_filter", b"_filter", "_page_size", b"_page_size", "_page_token", b"_page_token", "_view", b"_view", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "view", b"view"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_filter", b"_filter"]) -> typing_extensions.Literal["filter"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_size", b"_page_size"]) -> typing_extensions.Literal["page_size"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_page_token", b"_page_token"]) -> typing_extensions.Literal["page_token"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___ListOperatorDefinitionsRequest = ListOperatorDefinitionsRequest

@typing_extensions.final
class ListOperatorDefinitionsResponse(google.protobuf.message.Message):
    """ListOperatorDefinitionsResponse contains a list of operator definitions."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_DEFINITIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    TOTAL_SIZE_FIELD_NUMBER: builtins.int
    @property
    def operator_definitions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___OperatorDefinition]:
        """A list of operator definition resources."""
    next_page_token: builtins.str
    """Next page token."""
    total_size: builtins.int
    """Total number of operator definitions."""
    def __init__(
        self,
        *,
        operator_definitions: collections.abc.Iterable[global___OperatorDefinition] | None = ...,
        next_page_token: builtins.str = ...,
        total_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["next_page_token", b"next_page_token", "operator_definitions", b"operator_definitions", "total_size", b"total_size"]) -> None: ...

global___ListOperatorDefinitionsResponse = ListOperatorDefinitionsResponse

@typing_extensions.final
class GetOperatorDefinitionRequest(google.protobuf.message.Message):
    """GetOperatorDefinitionRequest represents a request to fetch the details of a
    operator definition.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VIEW_FIELD_NUMBER: builtins.int
    name: builtins.str
    """The resource name of the operator definition, which allows its access by ID.
    - Format: `operator-definitions/{id}`.
    """
    view: global___ComponentDefinition.View.ValueType
    """View allows clients to specify the desired resource view in the response."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        view: global___ComponentDefinition.View.ValueType | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["_view", b"_view", "view", b"view"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["_view", b"_view", "name", b"name", "view", b"view"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["_view", b"_view"]) -> typing_extensions.Literal["view"] | None: ...

global___GetOperatorDefinitionRequest = GetOperatorDefinitionRequest

@typing_extensions.final
class GetOperatorDefinitionResponse(google.protobuf.message.Message):
    """GetOperatorDefinitionResponse contains the requested operator definition."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATOR_DEFINITION_FIELD_NUMBER: builtins.int
    @property
    def operator_definition(self) -> global___OperatorDefinition:
        """The operator definition resource."""
    def __init__(
        self,
        *,
        operator_definition: global___OperatorDefinition | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["operator_definition", b"operator_definition"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["operator_definition", b"operator_definition"]) -> None: ...

global___GetOperatorDefinitionResponse = GetOperatorDefinitionResponse
